@@ -30,8 +30,15 @@
 #include <linux/completion.h>
 
 #include <linux/dma-buf.h>
+#include <linux/vt_kern.h>
+#if KERNEL_VERSION(5, 4, 0) <= LINUX_VERSION_CODE || defined(EL8)
+#include <linux/compiler_attributes.h>
+#endif
 
-#if KERNEL_VERSION(5, 16, 0) <= LINUX_VERSION_CODE || defined(EL9)
+/* Import of DMA_BUF namespace was reverted in EL8 */
+#if KERNEL_VERSION(6, 13, 0) <= LINUX_VERSION_CODE
+MODULE_IMPORT_NS("DMA_BUF");
+#elif KERNEL_VERSION(5, 16, 0) <= LINUX_VERSION_CODE || defined(EL9)
 MODULE_IMPORT_NS(DMA_BUF);
 #endif
 
@@ -104,6 +111,8 @@ struct evdi_painter {
 	struct completion ddcci_response_received;
 	char *ddcci_buffer;
 	unsigned int ddcci_buffer_length;
+	struct notifier_block vt_notifier;
+	int fg_console;
 };
 
 static void expand_rect(struct drm_clip_rect *a, const struct drm_clip_rect *b)
@@ -500,6 +509,7 @@ static void evdi_painter_send_dpms(struct evdi_painter *painter, int mode)
 {
 	struct drm_pending_event *event = create_dpms_event(mode);
 
+	EVDI_TEST_HOOK(evdi_testhook_painter_send_dpms(mode));
 	evdi_painter_send_event(painter, event);
 }
 
@@ -696,13 +706,12 @@ void evdi_painter_send_update_ready_if_needed(struct evdi_painter *painter)
 
 static const char * const dpms_str[] = { "on", "standby", "suspend", "off" };
 
-void evdi_painter_dpms_notify(struct evdi_device *evdi, int mode)
+void evdi_painter_dpms_notify(struct evdi_painter *painter, int mode)
 {
-	struct evdi_painter *painter = evdi->painter;
 	const char *mode_str;
 
 	if (!painter) {
-		EVDI_WARN("(card%d) Painter does not exist!", evdi->dev_index);
+		EVDI_WARN("Painter does not exist!");
 		return;
 	}
 
@@ -711,6 +720,11 @@ void evdi_painter_dpms_notify(struct evdi_device *evdi, int mode)
 
 	switch (mode) {
 	case DRM_MODE_DPMS_ON:
+		painter->fg_console = fg_console;
+#if KERNEL_VERSION(5, 4, 0) <= LINUX_VERSION_CODE || defined(EL8)
+		fallthrough;
+#else
+#endif
 	case DRM_MODE_DPMS_STANDBY:
 	case DRM_MODE_DPMS_SUSPEND:
 	case DRM_MODE_DPMS_OFF:
@@ -719,8 +733,8 @@ void evdi_painter_dpms_notify(struct evdi_device *evdi, int mode)
 	default:
 		mode_str = "unknown";
 	};
-	EVDI_INFO("(card%d) Notifying display power state: %s",
-		   evdi->dev_index, mode_str);
+	EVDI_INFO("(card%d) Notifying display power state: %s\n",
+		   painter->drm_device->primary->index, mode_str);
 	evdi_painter_send_dpms(painter, mode);
 }
 
@@ -1177,6 +1191,38 @@ static void evdi_send_events_work(struct work_struct *work)
 	schedule_delayed_work(&painter->send_events_work, msecs_to_jiffies(5));
 }
 
+#define vt_notifier_block_to_evdi_painter(x) container_of(x, struct evdi_painter, vt_notifier)
+static int evdi_painter_vt_notifier_call(struct notifier_block *blk,
+			    __always_unused unsigned long code, __always_unused void *_param)
+{
+	struct evdi_painter *painter = vt_notifier_block_to_evdi_painter(blk);
+
+	if (painter->is_connected && fg_console != painter->fg_console && !painter->needs_full_modeset) {
+		EVDI_INFO("(card%d) VT switch detected\n", painter->drm_device->primary->index);
+		evdi_painter_dpms_notify(painter, DRM_MODE_DPMS_OFF);
+		evdi_painter_force_full_modeset(painter);
+	}
+
+	return NOTIFY_OK;
+}
+
+
+static void evdi_painter_register_to_vt(struct evdi_painter *painter)
+{
+	painter->vt_notifier.notifier_call = evdi_painter_vt_notifier_call;
+	register_vt_notifier(&painter->vt_notifier);
+
+	EVDI_TEST_HOOK(evdi_testhook_painter_vt_register(&painter->vt_notifier));
+}
+
+static void evdi_painter_unregister_from_vt(struct evdi_painter *painter)
+{
+	unregister_vt_notifier(&painter->vt_notifier);
+	painter->vt_notifier.notifier_call = NULL;
+
+	EVDI_TEST_HOOK(evdi_testhook_painter_vt_register(&painter->vt_notifier));
+}
+
 int evdi_painter_init(struct evdi_device *dev)
 {
 	EVDI_CHECKPT();
@@ -1189,6 +1235,8 @@ int evdi_painter_init(struct evdi_device *dev)
 		dev->painter->crtc = NULL;
 		dev->painter->vblank = NULL;
 		dev->painter->drm_device = dev->ddev;
+		evdi_painter_register_to_vt(dev->painter);
+
 		INIT_LIST_HEAD(&dev->painter->pending_events);
 		INIT_DELAYED_WORK(&dev->painter->send_events_work,
 			evdi_send_events_work);
@@ -1207,6 +1255,7 @@ void evdi_painter_cleanup(struct evdi_painter *painter)
 	}
 
 	painter_lock(painter);
+	evdi_painter_unregister_from_vt(painter);
 	kfree(painter->edid);
 	painter->edid_length = 0;
 	painter->edid = NULL;
